@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -270,9 +270,14 @@ pyglib_error_check(GError **error)
     }
 
     exc_instance = PyObject_CallFunction(exc_type, "z", (*error)->message);
-    PyObject_SetAttrString(exc_instance, "domain",
-			   d=_PyUnicode_FromString(g_quark_to_string((*error)->domain)));
-    Py_DECREF(d);
+
+    if ((*error)->domain) {
+	PyObject_SetAttrString(exc_instance, "domain",
+			       d=_PyUnicode_FromString(g_quark_to_string((*error)->domain)));
+	Py_DECREF(d);
+    }
+    else
+	PyObject_SetAttrString(exc_instance, "domain", Py_None);
 
     PyObject_SetAttrString(exc_instance, "code",
 			   d=_PyLong_FromLong((*error)->code));
