@@ -16,18 +16,11 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
 # USA
 
 # this can go when things are a little further along
 
-try:
-    import ltihooks
-    ltihooks # pyflakes
-    del ltihooks
-except ImportError:
-    pass
-
 import sys
 
 from glib import spawn_async, idle_add, timeout_add, timeout_add_seconds, \
@@ -52,10 +45,10 @@ from glib import SPAWN_LEAVE_DESCRIPTORS_OPEN, SPAWN_DO_NOT_REAP_CHILD, \
      OPTION_ERROR_FAILED, OPTION_REMAINING, OPTION_ERROR
 
 from gobject.constants import *
-from _gobject import *
+from gobject._gobject import *
 _PyGObject_API = _gobject._PyGObject_API
 
-from propertyhelper import property
+from gobject.propertyhelper import property
 
 sys.modules['gobject.option'] = option
 
